==> nextcloud-app-tasks-0.13.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/hr.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Važno",
    "Today" : "Danas",
    "Week" : "Tjedan",
    "All" : "Sve",
    "Current" : "Trenutno",
    "Completed" : "Završeno",
    "Tasks" : "Zadaci",
    "The Tasks app for Nextcloud" : "Aplikacija Zadaci za Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Nakon što je omogućen, novi izbornik Zadaci pojavit će se u izborniku Nextcloudove aplikacije. Iz njega možete dodavati i brisati zadatke, uređivati njihov naslov, opis, datume početka i završetka i označavati ih kao važne. Zadaci se mogu dijeliti između korisnika. Zadaci se mogu sinkronizirati s pomoću kalendara CalDav (svaki popis zadataka povezan je s Nextcloudovim kalendarom radi sinkronizacije s lokalnim klijentom – Thunderbird, Evolution, KDE Kontact, iCal... – jednostavno dodajte kalendar kao udaljeni kalendar u svojem klijentu). Svoje zadatke možete preuzeti u obliku ICS datoteka s pomoću gumba za preuzimanje u kalendaru.",
    "Add List…" : "Dodaj popis…",
    "New List" : "Novi popis",
    "Cancel" : "Odustani",
    "Save" : "Spremi",
    "The name \"{calendar}\" is already used." : "Naziv „{calendar}” je već iskorišten.",
    "An empty name is not allowed." : "Prazan naziv nije dopušten.",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "can edit" : "uređivanje moguće",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "Unable to delete the share." : "Nije moguće izbrisati dijeljenje.",
    "Unable to change permissions." : "Nije moguće promijeniti dopuštenja.",
    "Edit" : "Uredi",
    "Copy private link" : "Kopiraj privatnu poveznicu",
    "Copied" : "Kopirano",
    "Can not copy" : "Nije moguće kopirati",
    "Download" : "Preuzmi",
    "Delete" : "Izbriši",
    "Unshare" : "Prestani dijeliti",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Time će se izbrisati kalendar „{calendar}” i svi pripadajući događaji i zadaci.",
    "This will unshare the calendar \"{calendar}\"." : "Time će se prestati dijeliti kalendar „{calendar}“.",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dijeljeno s {num} entitetom","Dijeljeno s {num} entiteta","Dijeljeno s {num} entiteta"],
    "Default list" : "Zadani popis",
    "Visibility of Smart Collections" : "Vidljivost pametnih zbirki",
    "Hidden" : "Skriveno",
    "Visible" : "Vidljivo",
    "Automatic" : "Automatsko",
    "Delete all completed tasks." : "Izbriši sve završene zadatke.",
    "Delete completed tasks." : "Izbriši završene zadatke.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Izbrisani su svi završeni zadaci iz kalendara „{calendar}”.",
    "No errors" : "Nema pogrešaka",
    "Open your browser console for more details" : "Za više pojedinosti otvorite konzolu preglednika",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Time ćete izbrisati {taskCount} završeni zadatak i njegove podzadatke iz kalendara „{calendar}”.","Time ćete izbrisati {taskCount} završenih zadataka i njihove podzadatke iz kalendara „{calendar}”.","Time ćete izbrisati {taskCount} završenih zadataka i njihove podzadatke iz kalendara „{calendar}”."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nije uspjelo brisanje {failedCount} zadatka.","Nije uspjelo brisanje {failedCount} zadataka.","Nije uspjelo brisanje {failedCount} zadataka."],
    "Load all completed tasks." : "Učitaj sve završene zadatke.",
    "Change sort order" : "Promijeni redoslijed razvrstavanja",
    "Relevance" : "Važnost",
    "Sort by completed state, due date, priority, start date and summary." : "Razvrstaj prema stanju, datumu dospijeća, prioritetu, datumu početka i sažetku.",
    "Start date" : "Datum početka",
    "Sort by start date and summary." : "Razvrstaj prema datumu početka i sažetku.",
    "Due date" : "Datum dospijeća",
    "Sort by due date and summary." : "Razvrstaj prema datumu dospijeća i sažetku.",
    "Created date" : "Datum stvaranja",
    "Sort by created date and summary." : "Razvrstaj prema datumu stvaranja i sažetku.",
    "Last modified" : "Posljednja izmjena",
    "Sort by last-modified date and summary." : "Razvrstaj prema datumu posljednje izmjene i sažetku.",
    "Completed date" : "Datum završetka",
    "Sort by completed date." : "Razvrstaj prema datumu završetka.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Razvrstaj prema prioritetu i sažetku.",
    "Alphabetically" : "Abecedno",
    "Sort by summary and priority." : "Razvrstaj prema sažetku i prioritetu.",
    "Manually" : "Ručno",
    "Sort by manual order." : "Razvrstaj ručno.",
    "Task is completed" : "Zadatak je završen",
    "{complete} % completed" : "Završeno {complete} %",
    "Add subtask" : "Dodaj podzadatak",
    "Show subtasks" : "Prikaži podzadatke",
    "Hide subtasks" : "Sakrij podzadatke",
    "Show completed subtasks" : "Prikaži završene podzadatke",
    "Hide completed subtasks" : "Sakrij završene podzadatke",
    "Delete task" : "Izbriši zadatak",
    "[Yesterday]" : "[Jučer]",
    "[Today]" : "[Danas]",
    "[Tomorrow]" : "[Sutra]",
    "[Completed yesterday]" : "[Završeno jučer]",
    "[Completed today]" : "[Završeno danas]",
    "[Completed tomorrow]" : "[Završeno sutra]",
    "[Yesterday at] LT" : "[Jučer u] LT",
    "[Today at] LT" : "[Danas u] LT",
    "[Tomorrow at] LT" : "[Sutra u] LT",
    "L [at] LT" : "L [u] LT",
    "[Completed yesterday at] LT" : "[Završeno jučer u] LT",
    "[Completed today at] LT" : "[Završeno danas u] LT",
    "[Completed tomorrow at] LT" : "[Završeno sutra u] LT",
    "[Completed] L [at] LT" : "[Završeno] L [u] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podzadatak u „{task}”...",
    "An error occurred, unable to delete the task." : "Došlo je do pogreške, nije moguće izbrisati zadatak.",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Brisanje zadatka za {countdown} sekundu","Brisanje zadatka za {countdown} sekunde","Brisanje zadatka za {countdown} sekundi"],
    "Add a task to \"{task}\"…" : "Dodaj zadatak u „{task}”...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n završeni zadatak","%n završenih zadataka","%n završenih zadataka"],
    "Add an important task to \"{calendar}\"…" : "Dodaj važan zadatak u „{calendar}”...",
    "Add a task due today to \"{calendar}\"…" : "Dodajte zadatak za danas u „{calendar}”...",
    "Add a current task to \"{calendar}\"…" : "Dodaj trenutni zadatak u „{calendar}”...",
    "Add a task to \"{calendar}\"…" : "Dodajte zadatak u „{calendar}”...",
    "Tomorrow" : "Sutra",
    "Set start date" : "Postavi datum početka",
    "Set start time" : "Postavi vrijeme početka",
    "Set due date" : "Postavi datum dospijeća",
    "Set due time" : "Postavi vrijeme dospijeća",
    "All day" : "Cijeli dan",
    "Select a calendar" : "Odaberi kalendar",
    "Select a classification" : "Odaberi klasifikaciju",
    "Select a status" : "Odaberi status",
    "Select categories" : "Odaberi kategorije",
    "Add this as a new category" : "Dodaj kao novu kategoriju",
    "Loading task from server." : "Učitavanje zadatka s poslužitelja.",
    "Task not found!" : "Zadatak nije pronađen!",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "Needs action" : "Potrebna je radnja",
    "In process" : "U tijeku",
    "Canceled" : "Otkazano",
    "[Starts today]" : "[Počinje danas]",
    "[Starts tomorrow]" : "[Počinje sutra]",
    "[Starts on] LL" : "[Počinje] LL",
    "[Started yesterday]" : "[Počeo jučer]",
    "[Started on] LL" : "[Počeo] LL",
    "[Started today at] LT" : "[Počeo danas u] LT",
    "[Starts today at] LT" : "[Počinje danas u] LT",
    "[Starts tomorrow at] LT" : "[Počinje sutra u] LT",
    "[Starts on] LL [at] LT" : "[Počinje] LL [u] LT",
    "[Started yesterday at] LT" : "[Počeo jučer u] LT",
    "[Started on] LL [at] LT" : "[Počeo] LL [u] LT",
    "[Due today]" : "[Treba završiti danas]",
    "[Due tomorrow]" : "[Treba završiti sutra]",
    "[Due on] LL" : "[Treba završiti] LL",
    "[Was due yesterday]" : "[Trebao je biti završen jučer]",
    "[Was due on] LL" : "[Trebao je biti završen] LL",
    "[Was due today at] LT" : "[Trebao je biti završen danas u] LT",
    "[Due today at] LT" : "[Treba završiti danas u] LT",
    "[Due tomorrow at] LT" : "[Treba završiti sutra u] LT",
    "[Due on] LL [at] LT" : "[Treba završiti] LL [u] LT",
    "[Was due yesterday at] LT" : "[Trebao je biti završen jučer u] LT",
    "[Was due on] LL [at] LT" : "[Trebao je biti završen] LL [u] LT",
    "Last modified {date}" : "Posljednja izmjena {date}",
    "Created {date}" : "Stvoreno {date}",
    "Completed {date}" : "Završeno {date}",
    "No priority assigned" : "Nije dodijeljen prioritet",
    "Priority {priority}: high" : "Prioritet {priority}: visok",
    "Priority {priority}: medium" : "Prioritet {priority}: srednji",
    "Priority {priority}: low" : "Prioritet {priority}: nizak",
    "{percent} % completed" : "Završeno {percent} %",
    "Successfully created the task." : "Zadatak je uspješno stvoren.",
    "Could not delete the task." : "Zadatak nije moguće izbrisati.",
    "Synchronizing to the server." : "Sinkronizacija s poslužiteljem.",
    "Task successfully saved to server." : "Zadatak je uspješno spremljen na poslužitelj.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nije moguće ažurirati zadatak jer je promijenjen na poslužitelju. Kliknite kako biste ga osvježili, a lokalne promjene se odbacuju.",
    "Could not update the task." : "Zadatak nije moguće ažurirati.",
    "Successfully updated the task." : "Zadatak je uspješno ažuriran.",
    "Task successfully moved to new calendar." : "Zadatak je uspješno premješten u novi kalendar.",
    "An error occurred" : "Došlo je do pogreške"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/hr.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Nadolazeći zadaci",
    "Important" : "Važno",
    "Today" : "Danas",
    "Week" : "Tjedan",
    "All" : "Sve",
    "Current" : "Trenutno",
    "Completed" : "Završeno",
    "Tasks" : "Zadaci",
    "The Tasks app for Nextcloud" : "Aplikacija Zadaci za Nextcloud",
    "Default list" : "Zadani popis",
    "Visibility of Smart Collections" : "Vidljivost pametnih zbirki",
    "Hidden" : "Skriveno",
    "Visible" : "Vidljivo",
    "Automatic" : "Automatsko",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "Can edit" : "Uređivanje moguće",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "Unable to delete the share." : "Nije moguće izbrisati dijeljenje.",
    "Unable to change permissions." : "Nije moguće promijeniti dopuštenja.",
    "Edit" : "Uredi",
    "Copy private link" : "Kopiraj privatnu poveznicu",
    "Copied" : "Kopirano",
    "Cannot copy" : "Nije moguće kopirati",
    "Export" : "Izvoz",
    "Delete" : "Izbriši",
    "Unshare" : "Prestani dijeliti",
    "Save" : "Spremi",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Time će se izbrisati kalendar „{calendar}” i svi pripadajući događaji i zadaci.",
    "This will unshare the calendar \"{calendar}\"." : "Time će se prestati dijeliti kalendar „{calendar}“.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Time će se izbrisati popis „{list}” i svi pripadajući zadaci.",
    "This will unshare the list \"{list}\"." : "Time će se prestati dijeliti popis „{list}“.",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "List link copied to clipboard." : "Poveznica popisa kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "List link could not be copied to clipboard." : "Poveznica popisa nije kopirana u međuspremnik.",
    "The name \"{calendar}\" is already used." : "Naziv „{calendar}” je već iskorišten.",
    "An empty name is not allowed." : "Prazan naziv nije dopušten.",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "An error occurred, unable to delete the list." : "Došlo je do pogreške, nije moguće izbrisati popis.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Brisanje popisa za {countdown} sekundu","Brisanje popisa za {countdown} sekunde","Brisanje popisa za {countdown} sekundi"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Prestanak dijeljenja popisa za {countdown} sekundu","Prestanak dijeljenja popisa za {countdown} sekunde","Prestanak dijeljenja popisa za {countdown} sekundi"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dijeljeno s {num} entitetom","Dijeljeno s {num} entiteta","Dijeljeno s {num} entiteta"],
    "Trash bin" : "Kanta za smeće",
    "Loading deleted calendars, tasks and events." : "Učitavanje izbrisanih kalendara, zadataka i događaja.",
    "You do not have any deleted calendars, tasks or events." : "Nemate izbrisanih kalendara, zadataka ili događaja.",
    "Name" : "Naziv",
    "Deleted" : "Izbrisano",
    "Restore" : "Vrati",
    "Delete permanently" : "Trajno izbrišite",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "Untitled task" : "Zadatak bez naslova",
    "Untitled event" : "Događaj bez naslova",
    "Untitled item" : "Stavka bez naslova",
    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elementi u kanti za smeće brišu se nakon {numDays} dan","Elementi u kanti za smeće brišu se nakon {numDays} dana","Elementi u kanti za smeće brišu se nakon {numDays} dana"],
    "Select a calendar" : "Odaberi kalendar",
    "Set date" : "Postavi datum",
    "Set time" : "Postavi vrijeme",
    "Delete date" : "Izbriši datum",
    "Click here to add a note." : "Kliknite ovdje za dodavanje bilješke.",
    "Set value" : "Postavi vrijednost",
    "Delete value" : "Izbriši vrijednost",
    "Add this as a new tag" : "Dodaj kao novu oznaku",
    "No tag available. Create one!" : "Nema dostupnih oznaka. Stvorite je!",
    "Delete all completed tasks." : "Izbriši sve završene zadatke.",
    "Delete completed tasks." : "Izbriši završene zadatke.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Izbrisani su svi završeni zadaci iz kalendara „{calendar}”.",
    "No errors" : "Nema pogrešaka",
    "Open your browser console for more details" : "Za više pojedinosti otvorite konzolu preglednika",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Time ćete izbrisati {taskCount} završeni zadatak i njegove podzadatke iz kalendara „{calendar}”.","Time ćete izbrisati {taskCount} završenih zadataka i njihove podzadatke iz kalendara „{calendar}”.","Time ćete izbrisati {taskCount} završenih zadataka i njihove podzadatke iz kalendara „{calendar}”."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nije uspjelo brisanje {failedCount} zadatka.","Nije uspjelo brisanje {failedCount} zadataka.","Nije uspjelo brisanje {failedCount} zadataka."],
    "Add an important task to \"{calendar}\"…" : "Dodaj važan zadatak u „{calendar}”...",
    "Add a task due today to \"{calendar}\"…" : "Dodajte zadatak za danas u „{calendar}”...",
    "Add a current task to \"{calendar}\"…" : "Dodaj trenutni zadatak u „{calendar}”...",
    "Add a task to \"{calendar}\"…" : "Dodajte zadatak u „{calendar}”...",
    "Load all completed tasks." : "Učitaj sve završene zadatke.",
    "Change sort order" : "Promijeni redoslijed razvrstavanja",
    "Relevance" : "Važnost",
    "Sort by completed state, due date, priority, start date and summary." : "Razvrstaj prema stanju, datumu dospijeća, prioritetu, datumu početka i sažetku.",
    "Start date" : "Datum početka",
    "Sort by start date and summary." : "Razvrstaj prema datumu početka i sažetku.",
    "Due date" : "Datum dospijeća",
    "Sort by due date and summary." : "Razvrstaj prema datumu dospijeća i sažetku.",
    "Created date" : "Datum stvaranja",
    "Sort by created date and summary." : "Razvrstaj prema datumu stvaranja i sažetku.",
    "Last modified" : "Posljednja izmjena",
    "Sort by last-modified date and summary." : "Razvrstaj prema datumu posljednje izmjene i sažetku.",
    "Completed date" : "Datum završetka",
    "Sort by completed date." : "Razvrstaj prema datumu završetka.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Razvrstaj prema prioritetu i sažetku.",
    "Alphabetically" : "Abecedno",
    "Sort by summary and priority." : "Razvrstaj prema sažetku i prioritetu.",
    "Manually" : "Ručno",
    "Sort by manual order." : "Razvrstaj ručno.",
    "{complete} % completed" : "Završeno {complete} %",
    "Task has hidden subtasks" : "Zadatak ima skrivene podzadatke",
    "Task is pinned" : "Zadatak je prikvačen",
    "Task has a note" : "Zadatak ima bilješku",
    "Add subtask" : "Dodaj podzadatak",
    "Show subtasks" : "Prikaži podzadatke",
    "Hide subtasks" : "Sakrij podzadatke",
    "Show closed subtasks" : "Prikaži zatvorene podzadatke",
    "Hide closed subtasks" : "Sakrij zatvorene podzadatke",
    "Delete task" : "Izbriši zadatak",
    "Toggle starred" : "Uključi/isključi zvjezdicu",
    "[Yesterday]" : "[Jučer]",
    "[Today]" : "[Danas]",
    "[Tomorrow]" : "[Sutra]",
    "[Completed yesterday]" : "[Završeno jučer]",
    "[Completed today]" : "[Završeno danas]",
    "[Completed tomorrow]" : "[Završeno sutra]",
    "[Yesterday at] LT" : "[Jučer u] LT",
    "[Today at] LT" : "[Danas u] LT",
    "[Tomorrow at] LT" : "[Sutra u] LT",
    "L [at] LT" : "L [u] LT",
    "[Completed yesterday at] LT" : "[Završeno jučer u] LT",
    "[Completed today at] LT" : "[Završeno danas u] LT",
    "[Completed tomorrow at] LT" : "[Završeno sutra u] LT",
    "[Completed] L [at] LT" : "[Završeno] L [u] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podzadatak u „{task}”...",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Brisanje zadatka za {countdown} sekundu","Brisanje zadatka za {countdown} sekunde","Brisanje zadatka za {countdown} sekundi"],
    "Task is completed" : "Zadatak je završen",
    "Create a new task" : "Stvori novi zadatak",
    "Task summary" : "Sažetak zadatka",
    "Cancel" : "Odustani",
    "Create task" : "Stvori zadatak",
    "Creating the new task…" : "Stvaranje novog zadatka...",
    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ je dodano u „{calendar}“",
    "Close" : "Zatvori",
    "Open task" : "Otvori zadatak",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n završeni zadatak","%n završenih zadataka","%n završenih zadataka"],
    "Tomorrow" : "Sutra",
    "Add List…" : "Dodaj popis…",
    "New List" : "Novi popis",
    "All day" : "Cijeli dan",
    "Unpin" : "Otkvači",
    "Pin" : "Prikvači",
    "Show in Calendar" : "Prikaži u kalendaru",
    "Edit title" : "Uredi naslov",
    "Details" : "Pojedinosti",
    "Select a classification" : "Odaberi klasifikaciju",
    "Select a status" : "Odaberi status",
    "Select tags" : "Odaberite oznake",
    "Notes" : "Bilješke",
    "Reminders" : "Podsjetnici",
    "Repeat" : "Ponovi",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "[Completed] L" : "[Završen] L",
    "[Completed last] dddd [at] LT" : "[Završen prošli] dddd [u] LT",
    "[Completed] dddd [at] LT" : "[Završen] dddd [u] LT",
    "[Last modified yesterday at] LT" : "[Posljednja izmjena jučer u] LT",
    "[Last modified today at] LT" : "[Posljednja izmjena danas u] LT",
    "[Last modified] L" : "[Posljednja izmjena] L",
    "[Last modified last] dddd [at] LT" : "[Posljednja izmjena prošli] dddd [u] LT",
    "[Last modified] dddd [at] LT" : "[Posljednja izmjena] dddd [u] LT",
    "[Created yesterday at] LT" : "[Stvoren jučer u] LT",
    "[Created today at] LT" : "[Stvoren danas u] LT",
    "[Created] L" : "[Stvoren] L",
    "[Created last] dddd [at] LT" : "[Stvoren prošli] dddd [u] LT",
    "[Created] dddd [at] LT" : "[Stvoren] dddd [u] LT",
    "Needs action" : "Potrebna je radnja",
    "In process" : "U tijeku",
    "Canceled" : "Otkazano",
    "Clear status" : "Izbriši status",
    "Loading task from server." : "Učitavanje zadatka s poslužitelja.",
    "Task not found!" : "Zadatak nije pronađen!",
    "[Starts today]" : "[Počinje danas]",
    "[Starts tomorrow]" : "[Počinje sutra]",
    "[Starts on] LL" : "[Počinje] LL",
    "[Started yesterday]" : "[Počeo jučer]",
    "[Started on] LL" : "[Počeo] LL",
    "[Started today at] LT" : "[Počeo danas u] LT",
    "[Starts today at] LT" : "[Počinje danas u] LT",
    "[Starts tomorrow at] LT" : "[Počinje sutra u] LT",
    "[Starts on] LL [at] LT" : "[Počinje] LL [u] LT",
    "[Started yesterday at] LT" : "[Počeo jučer u] LT",
    "[Started on] LL [at] LT" : "[Počeo] LL [u] LT",
    "Set start date" : "Postavi datum početka",
    "[Due today]" : "[Treba završiti danas]",
    "[Due tomorrow]" : "[Treba završiti sutra]",
    "[Due on] LL" : "[Treba završiti] LL",
    "[Was due yesterday]" : "[Trebao je biti završen jučer]",
    "[Was due on] LL" : "[Trebao je biti završen] LL",
    "[Was due today at] LT" : "[Trebao je biti završen danas u] LT",
    "[Due today at] LT" : "[Treba završiti danas u] LT",
    "[Due tomorrow at] LT" : "[Treba završiti sutra u] LT",
    "[Due on] LL [at] LT" : "[Treba završiti] LL [u] LT",
    "[Was due yesterday at] LT" : "[Trebao je biti završen jučer u] LT",
    "[Was due on] LL [at] LT" : "[Trebao je biti završen] LL [u] LT",
    "Set due date" : "Postavi datum dospijeća",
    "Priority {priority}: low" : "Prioritet {priority}: nizak",
    "Priority {priority}: medium" : "Prioritet {priority}: srednji",
    "Priority {priority}: high" : "Prioritet {priority}: visok",
    "No priority assigned" : "Nije dodijeljen prioritet",
    "{percent} % completed" : "Završeno {percent} %",
    "No upcoming tasks" : "Nema nadolazećih zadataka",
    "upcoming tasks" : "nadolazeći zadaci",
    "No tasks today" : "Danas nema zadataka",
    "Mark as done" : "Označi kao završeno",
    "No due date assigned" : "Nema dodijeljenog datuma dospijeća",
    "[Due yesterday]" : "[Trebao je biti završen jučer]",
    "[Due] L" : "[Treba biti završen] LL",
    "[Due yesterday at] LT" : "[Trebao je biti završen jučer u] LT",
    "[Due] L [at] LT" : "[Treba biti završen] L [u] LT",
    "Successfully created the task." : "Zadatak je uspješno stvoren.",
    "Could not delete the task." : "Zadatak nije moguće izbrisati.",
    "Synchronizing to the server." : "Sinkronizacija s poslužiteljem.",
    "Task successfully saved to server." : "Zadatak je uspješno spremljen na poslužitelj.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nije moguće ažurirati zadatak jer je promijenjen na poslužitelju. Kliknite kako biste ga osvježili, a lokalne promjene se odbacuju.",
    "Could not update the task." : "Zadatak nije moguće ažurirati.",
    "Successfully updated the task." : "Zadatak je uspješno ažuriran.",
    "Task successfully moved to new calendar." : "Zadatak je uspješno premješten u novi kalendar.",
    "An error occurred" : "Došlo je do pogreške",
    "Create a task" : "Stvori zadatak",
    "Message from {author} in {conversationName}" : "Poruka od {author} u {conversationName}"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
